# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.3] 2021-07-29
- massive FHIR model updates, incl Patient, Organizations, Datapacks etc.
- +some fixtures
- fix PyPi package

## [0.0.2]
- fix pypi upload

## [0.0.1]
### Changed
- install script for deploying on *buntu
- First version with decentralized plugin architecture. GDAPS plugins are separated.